# timecast

Performant, composable online learning

[![pypi](https://badgen.net/pypi/v/timecast)](https://pypi.org/project/timecast/)
[![pyversions](https://raw.githubusercontent.com/MinRegret/timecast/master/.github/badges/python_versions.svg?sanitize=true)](https://pypi.org/project/timecast)
[![security: bandit](https://raw.githubusercontent.com/MinRegret/timecast/master/.github/badges/bandit.svg?sanitize=true)](https://github.com/PyCQA/bandit)
[![Code style: black](https://raw.githubusercontent.com/MinRegret/timecast/master/.github/badges/black.svg?sanitize=true)](https://github.com/psf/black)
[![License: MIT](https://raw.githubusercontent.com/MinRegret/timecast/master/.github/badges/mit.svg?sanitize=true)](https://github.com/MinRegret/timecast/blob/master/LICENSE)

[![build](https://github.com/MinRegret/timecast/workflows/build/badge.svg)](https://github.com/MinRegret/timecast/actions)
[![coverage](https://badgen.net/codecov/c/github/MinRegret/timecast)](https://codecov.io/github/MinRegret/timecast)
[![Documentation Status](https://readthedocs.org/projects/timecast/badge/?version=latest)](https://timecast.readthedocs.io/en/latest/?badge=latest)
[![doc coverage](https://raw.githubusercontent.com/MinRegret/timecast/master/.github/badges/docstring_coverage.svg?sanitize=true)](https://readthedocs.org/projects/timecast/)
[![tests](https://img.shields.io/azure-devops/tests/MinRegret/timecast/2?compact_message)](https://dev.azure.com/MinRegret/timecast/_build?definitionId=2&_a=summary)

## Getting started

```bash
pip install timecast
```

To get the latest version (i.e., `master`):

```bash
pip install timecast-nightly
```

Please see documentation [here](https://timecast.readthedocs.io/en/latest).

## For developers

Please see
[CONTRIBUTING.md](https://github.com/MinRegret/timecast/blob/master/CONTRIBUTING.md)
for instructions.
